# Promethium 🐍

[![PyPI - Version](https://img.shields.io/pypi/v/promethium.svg)](https://pypi.org/project/promethium)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/promethium.svg)](https://pypi.org/project/promethium)

Library for calculating statistical distributions, written in pure Python with zero dependencies.

- To contribute to the project, check out the [contribution](https://github.com/ostromia/promethium/wiki/Contribution) wiki page.

- To view the documentation, check out the [documentation](https://github.com/ostromia/promethium/wiki/Documentation) wiki page.
